from cpl_core.dependency_injection import ServiceProviderABC
from cpl_query.extension import List
from graphene import ObjectType

from bot_data.abc.auto_role_repository_abc import AutoRoleRepositoryABC
from bot_data.abc.client_repository_abc import ClientRepositoryABC
from bot_data.abc.known_user_repository_abc import KnownUserRepositoryABC
from bot_data.abc.level_repository_abc import LevelRepositoryABC
from bot_data.abc.server_repository_abc import ServerRepositoryABC
from bot_data.abc.user_joined_server_repository_abc import UserJoinedServerRepositoryABC
from bot_data.abc.user_joined_voice_channel_abc import UserJoinedVoiceChannelRepositoryABC
from bot_data.abc.user_repository_abc import UserRepositoryABC
from bot_data.model.auto_role import AutoRole
from bot_data.model.client import Client
from bot_data.model.known_user import KnownUser
from bot_data.model.level import Level
from bot_data.model.server import Server
from bot_data.model.user import User
from bot_data.model.user_joined_server import UserJoinedServer
from bot_data.model.user_joined_voice_channel import UserJoinedVoiceChannel


class QueryABC(ObjectType):
    _auto_roles: List[AutoRole]
    _clients: List[Client]
    _known_users: List[KnownUser]
    _levels: List[Level]
    _servers: List[Server]
    _user_joined_servers: List[UserJoinedServer]
    _user_joined_voice_channel: List[UserJoinedVoiceChannel]
    _users: List[User]

    @classmethod
    @ServiceProviderABC.inject
    def init(
            cls,
            auto_roles: AutoRoleRepositoryABC,
            clients: ClientRepositoryABC,
            known_users: KnownUserRepositoryABC,
            levels: LevelRepositoryABC,
            servers: ServerRepositoryABC,
            user_joined_servers: UserJoinedServerRepositoryABC,
            user_joined_voice_channel: UserJoinedVoiceChannelRepositoryABC,
            users: UserRepositoryABC,
    ):
        cls._auto_roles = auto_roles.get_auto_roles()
        cls._clients = clients.get_clients()
        cls._known_users = known_users.get_users()
        cls._levels = levels.get_levels()
        cls._servers = servers.get_servers()
        cls._user_joined_servers = user_joined_servers.get_user_joined_servers()
        cls._user_joined_voice_channel = user_joined_voice_channel.get_user_joined_voice_channels()
        cls._users = users.get_users()
